@@ -10,7 +10,7 @@ def check_max_allowed_commits(commits: List, max_allowed_commits: int):
         return True
     elif len(commits) > max_allowed_commits:
         print(
-            f"Error: found {len(commits)} commits to check in the"
+            f"Error: found {len(commits)} commits to check in the "
             f"current branch while the maximum allowed number is {max_allowed_commits}"
         )
         sys.exit(1)
@@ -31,21 +31,8 @@ def check_commit(commits: List, merge_option: int) -> None:
         commits (List): List of commits to check
         merge_option (int): 0 or 1
     """
+    error_counter = ErrorCount()
     for c in commits:
-        commit = CommitValidator(commit=c)
-        if merge_option == 0:  # check merge commits have approvers
-            if commit.title.startswith("Merge"):
-                if not commit.validate_commit_merge():
-                    commit.error_count.increment_merge_error()
-            else:
-                if not commit.validate_commit_title():
-                    commit.error_count.increment_title_error()
-                if not commit.validate_commit_body():
-                    commit.error_count.increment_body_error()
-        elif merge_option == 1:
-            if not commit.validate_commit_title():
-                commit.error_count.increment_title_error()
-            if not commit.title.startswith("Merge"):
-                if not commit.validate_commit_body():
-                    commit.error_count.increment_body_error()
-    ErrorCount.error_report()
+        commit = CommitValidator(commit=c, error_counter=error_counter)
+        commit.perform_checks(merge_option)
+    error_counter.error_report()
